Enum style::values::specified::font::FontSize
[−]
[src]
pub enum FontSize {
Length(LengthOrPercentage),
Keyword(KeywordInfo),
Smaller,
Larger,
System(SystemFont),
}A specified font-size value
Variants
Length(LengthOrPercentage)A length; e.g. 10px.
Keyword(KeywordInfo)A keyword value, along with a ratio and absolute offset. The ratio in any specified keyword value will be 1 (with offset 0), but we cascade keywordness even after font-relative (percent and em) values have been applied, which is where the ratio comes in. The offset comes in if we cascaded a calc value, where the font-relative portion (em and percentage) will go into the ratio, and the remaining units all computed together will go into the offset. See bug 1355707.
Smallerfont-size: smaller
Largerfont-size: larger
System(SystemFont)Derived from a specified system font.
Methods
impl FontSize[src]
pub fn from_html_size(size: u8) -> Self[src]
pub fn to_computed_value_against(
&self,
context: &Context,
base_size: FontBaseSize
) -> FontSize[src]
&self,
context: &Context,
base_size: FontBaseSize
) -> FontSize
Compute it against a given base font size
impl FontSize[src]
pub fn system_font(f: SystemFont) -> Self[src]
Construct a system font value.
pub fn get_system(&self) -> Option<SystemFont>[src]
Obtain the system font, if any
pub fn medium() -> Self[src]
Get initial value for specified font size.
pub fn parse_quirky<'i, 't>(
context: &ParserContext,
input: &mut Parser<'i, 't>,
allow_quirks: AllowQuirks
) -> Result<FontSize, ParseError<'i>>[src]
context: &ParserContext,
input: &mut Parser<'i, 't>,
allow_quirks: AllowQuirks
) -> Result<FontSize, ParseError<'i>>
Parses a font-size, with quirks.
pub fn cascade_specified_font_size(
context: &mut Context,
specified_value: &FontSize,
computed: FontSize
)[src]
context: &mut Context,
specified_value: &FontSize,
computed: FontSize
)
Cascade font-size with specified value